@@ -29,47 +29,10 @@ LOG = logging.getLogger(__name__)
 
 
 class Cleanup(base.Base):
-    """
-    Cleanup Command Class.
-
-    This action has cleanup and is not enabled by default.
-    See the provisioner's documentation for further details.
-
-    .. program:: molecule cleanup
-
-    .. option:: molecule cleanup
-
-        Target the default scenario.
-
-    .. program:: molecule cleanup --scenario-name foo
-
-    .. option:: molecule cleanup --scenario-name foo
-
-        Targeting a specific scenario.
-
-    .. program:: molecule --debug cleanup
-
-    .. option:: molecule --debug cleanup
-
-        Executing with `debug`.
-
-    .. program:: molecule --base-config base.yml cleanup
-
-    .. option:: molecule --base-config base.yml cleanup
-
-        Executing with a `base-config`.
-
-    .. program:: molecule --env-file foo.yml cleanup
-
-    .. option:: molecule --env-file foo.yml cleanup
-
-        Load an env file to read variables when rendering
-        molecule.yml.
-    """
+    """Cleanup Command Class."""
 
     def execute(self, action_args=None):
-        """
-        Execute the actions necessary to cleanup the instances and returns \
+        """Execute the actions necessary to cleanup the instances and returns \
         None.
 
         :return: None
@@ -92,7 +55,8 @@ class Cleanup(base.Base):
 )
 def cleanup(ctx, scenario_name):  # pragma: no cover
     """Use the provisioner to cleanup any changes made to external systems during \
-    the stages of testing."""
+    the stages of testing.
+    """
     args = ctx.obj.get("args")
     subcommand = base._get_subcommand(__name__)
     command_args = {"subcommand": subcommand}
