@@ -29,53 +29,10 @@ LOG = logging.getLogger(__name__)
 
 
 class Converge(base.Base):
-    """
-    Converge Command Class.
+    """Converge Command Class."""
 
-    .. program:: molecule converge
-
-    .. option:: molecule converge
-
-        Target the default scenario.
-
-    .. program:: molecule converge --scenario-name foo
-
-    .. option:: molecule converge --scenario-name foo
-
-        Targeting a specific scenario.
-
-    .. program:: molecule converge -- -vvv --tags foo,bar
-
-    .. option:: molecule converge -- -vvv --tags foo,bar
-
-        Providing additional command line arguments to the `ansible-playbook`
-        command.  Use this option with care, as there is no sanitation or
-        validation of input.  Options passed on the CLI override options
-        provided in provisioner's `options` section of `molecule.yml`.
-
-    .. program:: molecule --debug converge
-
-    .. option:: molecule --debug converge
-
-        Executing with `debug`.
-
-    .. program:: molecule --base-config base.yml converge
-
-    .. option:: molecule --base-config base.yml converge
-
-        Executing with a `base-config`.
-
-    .. program:: molecule --env-file foo.yml converge
-
-    .. option:: molecule --env-file foo.yml converge
-
-        Load an env file to read variables from when rendering
-        molecule.yml.
-    """
-
-    def execute(self):
-        """
-        Execute the actions necessary to perform a `molecule converge` and \
+    def execute(self, action_args=None):
+        """Execute the actions necessary to perform a `molecule converge` and \
         returns None.
 
         :return: None
@@ -90,9 +47,7 @@ class Converge(base.Base):
     "--scenario-name",
     "-s",
     default=base.MOLECULE_DEFAULT_SCENARIO_NAME,
-    help="Name of the scenario to target. ({})".format(
-        base.MOLECULE_DEFAULT_SCENARIO_NAME
-    ),
+    help=f"Name of the scenario to target. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
 )
 @click.argument("ansible_args", nargs=-1, type=click.UNPROCESSED)
 def converge(ctx, scenario_name, ansible_args):  # pragma: no cover
