@@ -19,72 +19,27 @@
 #  DEALINGS IN THE SOFTWARE.
 """List Command Module."""
 
-from __future__ import print_function
+
+import logging
 
 import click
 from rich import box
 from rich.syntax import Syntax
 from rich.table import Table
 
-from molecule import logger, scenarios, text, util
+from molecule import scenarios, text, util
 from molecule.command import base
 from molecule.console import console
 from molecule.status import Status
 
-LOG = logger.get_logger(__name__)
+LOG = logging.getLogger(__name__)
 
 
 class List(base.Base):
-    """
-    List command shows information about current scenarios.
+    """List command shows information about current scenarios."""
 
-    .. program:: molecule list
-
-    .. option:: molecule list
-
-        Target the default scenario.
-
-    .. program:: molecule list --scenario-name foo
-
-    .. option:: molecule list --scenario-name foo
-
-        Targeting a specific scenario.
-
-    .. program:: molecule list --format plain
-
-    .. option:: molecule list  --format plain
-
-        Machine readable plain text output.
-
-    .. program:: molecule list --format yaml
-
-    .. option:: molecule list  --format yaml
-
-        Machine readable yaml output.
-
-    .. program:: molecule --debug list
-
-    .. option:: molecule --debug list
-
-        Executing with `debug`.
-
-    .. program:: molecule --base-config base.yml list
-
-    .. option:: molecule --base-config base.yml list
-
-        Executing with a `base-config`.
-
-    .. program:: molecule --env-file foo.yml list
-
-    .. option:: molecule --env-file foo.yml list
-
-        Load an env file to read variables from when rendering
-        molecule.yml.
-    """
-
-    def execute(self):
-        """
-        Execute the actions necessary to perform a `molecule list` and \
+    def execute(self, action_args=None):
+        """Execute the actions necessary to perform a `molecule list` and \
         returns None.
 
         :return: None
@@ -114,7 +69,7 @@ def list(ctx, scenario_name, format):  # pragma: no cover
         statuses.extend(base.execute_subcommand(scenario.config, subcommand))
 
     headers = [text.title(name) for name in Status._fields]
-    if format == "simple" or format == "plain":
+    if format in ["simple", "plain"]:
         table_format = format  # "simple"
 
         if format == "plain":
@@ -126,8 +81,7 @@ def list(ctx, scenario_name, format):  # pragma: no cover
 
 
 def _print_tabulate_data(headers, data, table_format):  # pragma: no cover
-    """
-    Show the tabulate data on the screen and returns None.
+    """Show the tabulate data on the screen and returns None.
 
     :param headers: A list of column headers.
     :param data:  A list of tabular data to display.
