@@ -126,8 +126,7 @@ class Config(metaclass=NewInitCaller):
         # https://github.com/ansible/ansible/pull/70007
         if self.runtime.version >= Version("2.10.0.dev0"):
             return "ANSIBLE_COLLECTIONS_PATH"
-        else:
-            return "ANSIBLE_COLLECTIONS_PATHS"
+        return "ANSIBLE_COLLECTIONS_PATHS"
 
     @property
     def config_file(self):
@@ -174,15 +173,21 @@ class Config(metaclass=NewInitCaller):
         dependency_name = self.config["dependency"]["name"]
         if dependency_name == "galaxy":
             return ansible_galaxy.AnsibleGalaxy(self)
-        elif dependency_name == "shell":
+        if dependency_name == "shell":
             return shell.Shell(self)
+        return None
 
     @cached_property
     def driver(self):
         driver_name = self._get_driver_name()
         driver = None
 
-        driver = api.drivers(config=self)[driver_name]
+        api_drivers = api.drivers(config=self)
+        if driver_name not in api_drivers:
+            msg = f"Failed to find driver {driver_name}. Please ensure that the driver is correctly installed."
+            util.sysexit_with_message(msg)
+
+        driver = api_drivers[driver_name]
         driver.name = driver_name
 
         return driver
@@ -236,10 +241,12 @@ class Config(metaclass=NewInitCaller):
                 myState.change_state("molecule_yml_date_modified", modTime)
             elif myState.molecule_yml_date_modified != modTime:
                 LOG.warning(
-                    f"The scenario config file ('{self.molecule_file}') has been modified since the scenario was created. "
-                    + "If recent changes are important, reset the scenario with 'molecule destroy' to clean up created items or "
-                    + "'molecule reset' to clear current configuration.",
+                    "The scenario config file ('%s') has been modified since the scenario was created. "
+                    "If recent changes are important, reset the scenario with 'molecule destroy' to clean up created items or "
+                    "'molecule reset' to clear current configuration.",
+                    self.molecule_file,
                 )
+
         return state.State(self)
 
     @cached_property
