@@ -1,5 +1,4 @@
 """PyTest Fixtures."""
-from __future__ import absolute_import
 
 import os
 
@@ -14,9 +13,10 @@ def pytest_runtest_setup(item):
         pytest.skip("Test requires testinfra", allow_module_level=True)
     if "MOLECULE_INVENTORY_FILE" in os.environ:
         pytest.testinfra_hosts = testinfra.utils.ansible_runner.AnsibleRunner(
-            os.environ["MOLECULE_INVENTORY_FILE"]
+            os.environ["MOLECULE_INVENTORY_FILE"],
         ).get_hosts("all")
     else:
         pytest.skip(
-            "Test should run only from inside molecule.", allow_module_level=True
+            "Test should run only from inside molecule.",
+            allow_module_level=True,
         )
