@@ -19,7 +19,6 @@
 #  DEALINGS IN THE SOFTWARE.
 """Schema v3 Validation Module."""
 
-import importlib.resources as pkg_resources
 import json
 import logging
 import os
@@ -27,6 +26,7 @@ import os
 from jsonschema import validate as jsonschema_validate
 from jsonschema.exceptions import ValidationError
 
+from molecule import api
 from molecule.data import __file__ as data_module
 
 LOG = logging.getLogger(__name__)
@@ -39,22 +39,18 @@ def validate(c):
 
     schema_files = [os.path.dirname(data_module) + "/molecule.json"]
     driver_name = c["driver"]["name"]
+
     driver_schema_file = None
+    if driver_name in api.drivers():
+        driver_schema_file = api.drivers()[driver_name].schema_file()
 
-    if driver_name == "delegated":
-        driver_schema_file = os.path.dirname(data_module) + "/driver.json"
+    if driver_schema_file is None:
+        msg = f"Driver {driver_name} does not provide a schema."
+        LOG.warning(msg)
+    elif not os.path.exists(driver_schema_file):
+        msg = f"Schema {driver_schema_file} for driver {driver_name} not found."
+        LOG.warning(msg)
     else:
-        try:
-            with pkg_resources.path(f"molecule_{driver_name}", "driver.json") as p:
-                driver_schema_file = p.as_posix()
-        except FileNotFoundError:
-            msg = f"No schema found in {driver_name} driver."
-            LOG.warning(msg)
-        except ModuleNotFoundError:
-            msg = f"{driver_name} driver is not installed."
-            LOG.warning(msg)
-
-    if driver_schema_file:
         schema_files.append(driver_schema_file)
 
     for schema_file in schema_files:
@@ -75,7 +71,7 @@ def validate(c):
             ):
                 wrong_driver_name = str(exc.message.split()[0])
                 driver_name_err_msg = exc.schema["messages"]["anyOf"]
-                result.append(" ".join((wrong_driver_name, driver_name_err_msg)))
+                result.append(f"{wrong_driver_name} {driver_name_err_msg}")
             else:
                 result.append(exc.message)
 
