@@ -96,8 +96,7 @@ class Scenario:
     def directory(self):
         if self.config.molecule_file:
             return os.path.dirname(self.config.molecule_file)
-        else:
-            return os.getcwd()
+        return os.getcwd()
 
     @property
     def ephemeral_directory(self):
@@ -200,7 +199,6 @@ class Scenario:
             if not isinstance(result, list):
                 raise RuntimeError("Unexpected sequence type {result}.")
         except KeyError:
-            # TODO(retr0h): May change this handling in the future.
             pass
         return result
 
