@@ -5,7 +5,7 @@ import os
 import testinfra.utils.ansible_runner
 
 testinfra_hosts = testinfra.utils.ansible_runner.AnsibleRunner(
-    os.environ["MOLECULE_INVENTORY_FILE"]
+    os.environ["MOLECULE_INVENTORY_FILE"],
 ).get_hosts("all")
 
 
