@@ -31,22 +31,22 @@ class CommandBase(base.Base):
     """CommandBase Class."""
 
 
-@pytest.fixture
+@pytest.fixture()
 def _base_class():
     return CommandBase
 
 
-@pytest.fixture
+@pytest.fixture()
 def _instance(_base_class):
     return _base_class()
 
 
-@pytest.fixture
+@pytest.fixture()
 def _role_directory():
     return "."
 
 
-@pytest.fixture
+@pytest.fixture()
 def _command_args():
     return {
         "dependency_name": "galaxy",
@@ -58,10 +58,14 @@ def _command_args():
     }
 
 
-@pytest.fixture
+@pytest.fixture()
 def _molecule_file(_role_directory):
     return os.path.join(
-        _role_directory, "test-role", "molecule", "default", "molecule.yml"
+        _role_directory,
+        "test-role",
+        "molecule",
+        "default",
+        "molecule.yml",
     )
 
 
@@ -70,7 +74,7 @@ def test_valid(temp_dir, _molecule_file, _role_directory, _command_args, _instan
 
     data = util.safe_load_file(_molecule_file)
 
-    assert {} == schema_v3.validate(data)
+    assert not schema_v3.validate(data)
 
     cmd = ["yamllint", "-s", _molecule_file]
     result = util.run_command(cmd)
