@@ -29,7 +29,7 @@ from molecule.dependency.ansible_galaxy import roles
 @pytest.fixture()
 def _patched_ansible_galaxy_has_requirements_file(mocker):
     m = mocker.patch(
-        "molecule.dependency.ansible_galaxy.roles." "Roles._has_requirements_file",
+        "molecule.dependency.ansible_galaxy.roles.Roles._has_requirements_file",
     )
     m.return_value = True
 
