@@ -137,7 +137,7 @@ def run_command(
             "Molecule 3.2.0 dropped use of sh library, update plugin code to use new API. "
             "See https://github.com/ansible-community/molecule/issues/2678",
         )
-    elif cmd.__class__.__name__ == "BakedCommand":
+    if cmd.__class__.__name__ == "BakedCommand":
         env = dict(cmd.env, **env) if cmd.env and env else cmd.env or env
         args = cmd.cmd
     else:
@@ -175,7 +175,12 @@ def os_walk(directory, pattern, excludes=[], followlinks=False):
 
 def render_template(template, **kwargs):
     """Render a jinaj2 template."""
-    t = jinja2.Environment()
+    t = jinja2.Environment(
+        autoescape=jinja2.select_autoescape(
+            default_for_string=False,
+            default=False,
+        ),
+    )
     t = t.from_string(template)
 
     return t.render(kwargs)
@@ -379,7 +384,7 @@ def boolean(value: Any, strict=True) -> bool:
 
     if normalized_value in BOOLEANS_TRUE:
         return True
-    elif normalized_value in BOOLEANS_FALSE or not strict:
+    if normalized_value in BOOLEANS_FALSE or not strict:
         return False
 
     raise TypeError(
