@@ -29,33 +29,33 @@ log = logging.getLogger(__name__)
 
 
 class Ansible(Verifier):
-    """
-    `Ansible`_ is the default test verifier.
+    """`Ansible`_ is the default test verifier.
 
     Molecule executes a playbook (`verify.yml`) located in the role's
     `scenario.directory`.
 
-    .. code-block:: yaml
-
+    ``` yaml
         verifier:
           name: ansible
+    ```
 
     The testing can be disabled by setting ``enabled`` to False.
 
-    .. code-block:: yaml
-
+    ``` yaml
         verifier:
           name: ansible
           enabled: False
+    ```
 
     Environment variables can be passed to the verifier.
 
-    .. code-block:: yaml
+    ``` yaml
 
         verifier:
           name: ansible
           env:
             FOO: bar
+    ```
     """
 
     @property
@@ -71,7 +71,7 @@ class Ansible(Verifier):
         env = util.merge_dicts(os.environ, self._config.env)
         return util.merge_dicts(env, self._config.provisioner.env)
 
-    def execute(self):
+    def execute(self, action_args=None):
         if not self.enabled:
             msg = "Skipping, verifier is disabled."
             log.warning(msg)
@@ -80,7 +80,7 @@ class Ansible(Verifier):
         msg = "Running Ansible Verifier"
         log.info(msg)
 
-        self._config.provisioner.verify()
+        self._config.provisioner.verify(action_args)
 
         msg = "Verifier completed successfully."
         log.info(msg)
@@ -90,5 +90,5 @@ class Ansible(Verifier):
             "verifier": {
                 "type": "dict",
                 "schema": {"name": {"type": "string", "allowed": ["ansible"]}},
-            }
+            },
         }
